==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaWygaszajaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DecyzjaWygaszajaca extends GenericDPSObject {
    /**
     * DECYZJA_WYGASZAJACA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DECYZJA_WYGASZAJACA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * DECYZJA_WYGASZAJACA.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * DECYZJA_WYGASZAJACA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYGASZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWygaszenia;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_WYGASZAJACA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_WYGASZAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DECYZJA_WYGASZAJACA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * DECYZJA_WYGASZAJACA.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_WYGASZAJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_WYGASZAJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.DATA_WYGASZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWygaszenia() {
        return dataWygaszenia;
    }

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYGASZENIA
     *
     * @param dataWygaszenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWygaszenia(Date dataWygaszenia) {
        this.dataWygaszenia = dataWygaszenia;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaWygaszajaca other = (DecyzjaWygaszajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getDataWygaszenia() == null ? other.getDataWygaszenia() == null : this.getDataWygaszenia().equals(other.getDataWygaszenia()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getDataWygaszenia() == null) ? 0 : getDataWygaszenia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", nr=").append(nr);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", dataWygaszenia=").append(dataWygaszenia);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaWygaszajaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DecyzjaWygaszajaca extends GenericDPSObject {
    /**
     * DECYZJA_WYGASZAJACA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DECYZJA_WYGASZAJACA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * DECYZJA_WYGASZAJACA.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * DECYZJA_WYGASZAJACA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYGASZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWygaszenia;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_WYGASZAJACA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_WYGASZAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DECYZJA_WYGASZAJACA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * DECYZJA_WYGASZAJACA.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_WYGASZAJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_WYGASZAJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_WYGASZAJACA.DATA_WYGASZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWygaszenia() {
        return dataWygaszenia;
    }

    /**
     * DECYZJA_WYGASZAJACA.DATA_WYGASZENIA
     *
     * @param dataWygaszenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWygaszenia(Date dataWygaszenia) {
        this.dataWygaszenia = dataWygaszenia;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaWygaszajaca other = (DecyzjaWygaszajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getDataWygaszenia() == null ? other.getDataWygaszenia() == null : this.getDataWygaszenia().equals(other.getDataWygaszenia()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getDataWygaszenia() == null) ? 0 : getDataWygaszenia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", nr=").append(nr);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", dataWygaszenia=").append(dataWygaszenia);
        sb.append("]");
        return sb.toString();
    }
}
